Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2230)

Unified Diff: tests/lib/async/zone_future_run_async_test.dart

Issue 26151002: Rename runAsync to scheduleMicrotask. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Add test. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/lib/async/zone_empty_description_test.dart ('k') | tests/lib/async/zone_run_guarded_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/lib/async/zone_future_run_async_test.dart
diff --git a/tests/lib/async/zone_future_run_async_test.dart b/tests/lib/async/zone_future_run_async_test.dart
index ddfac1850be2e08c1545e4bf2e4e76947c54e701..32a23c1a9880a5eb867e7694139c2a542472c305 100644
--- a/tests/lib/async/zone_future_run_async_test.dart
+++ b/tests/lib/async/zone_future_run_async_test.dart
@@ -10,8 +10,8 @@ main() {
asyncStart();
Completer done = new Completer();
- // Make sure that the zones use the runAsync of their zones.
- int runAsyncCount = 0;
+ // Make sure that the zones use the scheduleMicrotask of their zones.
+ int scheduleMicrotaskCount = 0;
Completer completer;
Completer completer2;
Future future;
@@ -23,9 +23,9 @@ main() {
completer2.complete(-499);
future = new Future.value(42);
future2 = new Future.error(11);
- }, onRunAsync: (f) {
- runAsyncCount++;
- runAsync(f);
+ }, onScheduleMicrotask: (f) {
+ scheduleMicrotaskCount++;
+ scheduleMicrotask(f);
});
int openCallbackCount = 0;
@@ -58,7 +58,7 @@ main() {
});
done.future.whenComplete(() {
- Expect.equals(4, runAsyncCount);
+ Expect.equals(4, scheduleMicrotaskCount);
asyncEnd();
});
}
« no previous file with comments | « tests/lib/async/zone_empty_description_test.dart ('k') | tests/lib/async/zone_run_guarded_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698